@@ -18,10 +18,12 @@ public slots:
 
 public:
     DigitalClockWdg(QWidget *parent = 0);
+    void setId(QString &aAppletId);
 
 protected:
     void mouseReleaseEvent ( QMouseEvent * e );
     void mousePressEvent ( QMouseEvent * e );
+    void paintEvent(QPaintEvent *event);
 
 private slots:
     void showTime();
@@ -47,6 +49,8 @@ private:
     int m_blinking1;
     int m_blinking2;
     int m_tzOffset;
+    QString m_aplletId;
+    float m_transparency;
 };
 
 #endif
