@@ -26,6 +26,8 @@ int main(int argc, char *argv[])
     QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&clock);
     adaptor->setSettingsAvailable(true);
     QString aId = adaptor->getAppletId();
+    if (aId.isEmpty())
+        aId ="a";
     clock.setId(aId);
     QObject::connect(adaptor, SIGNAL(settingsRequested()), &clock, SLOT(showSettingsDialog()));
     QObject::connect(adaptor, SIGNAL(homescreenChanged(bool)), &clock, SLOT(homeScreenChanged(bool)));
