@@ -8,8 +8,15 @@
 #include "ui_settingsdialog.h"
 #include "dclocksettings.h"
 
-SettingsDialog::SettingsDialog(QWidget *parent) :
-    QDialog(parent),
+#define STR_VERSION "0.3.1"
+#define STR_CRLF "<br>"
+#define STR_QT_VERSION "<b>Qt 4.6.2</b>"
+#define STR_COPYRIGHT "Copyright (c) 2010 Avis"
+#define STR_EMAIL "<a href=\"mailto:avis@allnokia.ru\">avis@allnokia.ru</a>"
+#define STR_DONATE "<a href=https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=TBV3R4AU2PVHS>Donate</a>"
+
+SettingsDialog::SettingsDialog(QString &aAppletId, QWidget *parent) :
+    QDialog(parent), m_appletId(aAppletId),
     ui(new Ui::SettingsDialog)
 {
     ui->setupUi(this);
@@ -88,24 +95,25 @@ void SettingsDialog::btnColorClicked()
 
 void SettingsDialog::dumpSettings() const
 {
-    dclocksettings::getInstance().setColor(ui->labelColor->palette().color(QPalette::WindowText));
-    dclocksettings::getInstance().setShowSeconds(ui->checkBox->isChecked());
-    dclocksettings::getInstance().setTimeFormat(ui->cbTimeFormat->currentIndex());
+    dclocksettings::getInstance().setColor(m_appletId,ui->labelColor->palette().color(QPalette::WindowText));
+    dclocksettings::getInstance().setShowSeconds(m_appletId,ui->checkBox->isChecked());
+    dclocksettings::getInstance().setTimeFormat(m_appletId,ui->cbTimeFormat->currentIndex());
     int w = ui->spinWidth->value();
     int h = ui->spinHeight->value();
-    dclocksettings::getInstance().setSize(QSize(w,h));
+    dclocksettings::getInstance().setSize(m_appletId,QSize(w,h));
     if (ui->cbFont->currentIndex() == 0)
-        dclocksettings::getInstance().setLcd(true);
+        dclocksettings::getInstance().setLcd(m_appletId,true);
     else
-        dclocksettings::getInstance().setLcd(false);
-    dclocksettings::getInstance().setFont(m_font);
-    dclocksettings::getInstance().setBlinking(ui->chbBlink->isChecked());
+        dclocksettings::getInstance().setLcd(m_appletId,false);
+    dclocksettings::getInstance().setFont(m_appletId,m_font);
+    dclocksettings::getInstance().setBlinking(m_appletId,ui->chbBlink->isChecked());
     int tzOffset = ui->cbTZ->itemData(ui->cbTZ->currentIndex(),Qt::UserRole).toInt();
     int defOffest = calcOffset();
     if (tzOffset == defOffest)
-        dclocksettings::getInstance().setTZoffset(-50000);
+        dclocksettings::getInstance().setTZoffset(m_appletId,-50000);
     else
-        dclocksettings::getInstance().setTZoffset(tzOffset);
+        dclocksettings::getInstance().setTZoffset(m_appletId,tzOffset);
+    dclocksettings::getInstance().setTransparency(m_appletId,ui->hzSliderTransparency->value());
 }
 
 int SettingsDialog::calcOffset() const
@@ -119,18 +127,19 @@ int SettingsDialog::calcOffset() const
 
 void SettingsDialog::loadSettings()
 {
-    QColor dColor = dclocksettings::getInstance().getColor();
+    QColor dColor = dclocksettings::getInstance().getColor(m_appletId);
     QPalette qp = ui->labelColor->palette();
     qp.setColor(QPalette::WindowText,dColor);
     ui->labelColor->setPalette(qp);
-    ui->checkBox->setChecked(dclocksettings::getInstance().getShowSeconds());
-    ui->cbTimeFormat->setCurrentIndex(dclocksettings::getInstance().getTimeFormat());
-    QSize wSize = dclocksettings::getInstance().getSize();
+    ui->checkBox->setChecked(dclocksettings::getInstance().getShowSeconds(m_appletId));
+    ui->cbTimeFormat->setCurrentIndex(dclocksettings::getInstance().getTimeFormat(m_appletId));
+    QSize wSize = dclocksettings::getInstance().getSize(m_appletId);
     ui->spinWidth->setValue(wSize.width());
     ui->spinHeight->setValue(wSize.height());
-    ui->chbBlink->setChecked(dclocksettings::getInstance().getBlinking());
+    ui->chbBlink->setChecked(dclocksettings::getInstance().getBlinking(m_appletId));
+    ui->hzSliderTransparency->setValue(dclocksettings::getInstance().getTransparency(m_appletId));
 
-    int tzOffset = dclocksettings::getInstance().getTZoffset();
+    int tzOffset = dclocksettings::getInstance().getTZoffset(m_appletId);
     if (tzOffset == -50000)
     {
         // calc current time zone
@@ -144,12 +153,12 @@ void SettingsDialog::loadSettings()
     int i = ui->cbTZ->findData(tzOffset, int(Qt::UserRole));
     ui->cbTZ->setCurrentIndex(i);
 
-    if (dclocksettings::getInstance().getLcd())
+    if (dclocksettings::getInstance().getLcd(m_appletId))
         ui->cbFont->setCurrentIndex(0);
     else
     {
         bool found = false;
-        m_font = dclocksettings::getInstance().getFont();
+        m_font = dclocksettings::getInstance().getFont(m_appletId);
         QString fnt_family(m_font.family());
         int i;
         for (i = 1; i < ui->cbFont->count(); i++)
@@ -176,14 +185,17 @@ void SettingsDialog::loadSettings()
 
 void SettingsDialog::showAbout()
 {
-    QString msgText = tr("<b>DigiClock</b> 0.3.0<br>"
-                         "Using <b>Qt 4.6.2</b><br>"
-                         "Copyright (c) 2010 Avis<br>"
-                         "<a href=\"mailto:avis@allnokia.ru\">avis@allnokia.ru</a><br><br>"
-                         "Desktop widget, showing digital time");
-    msgText += "<br><br><a href=https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=TBV3R4AU2PVHS>Donate</a>";
-    QMessageBox::about(this, tr("About DigiClock"),
-                        msgText);
+    QString msgName = tr("DigiClock");
+    QString msgDeveloped = tr("Developed with");
+    QString msgDescr = tr("Desktop widget, showing digital time");
+    QString msgReports = tr("Send reports to:");
+    QString msgText = "<b>" + msgName + "</b> " + STR_VERSION + STR_CRLF;
+    msgText += msgDescr + STR_CRLF;
+    msgText += msgDeveloped + " " + STR_QT_VERSION + STR_CRLF + STR_CRLF;
+    msgText += msgReports + " " + STR_EMAIL + STR_CRLF;
+    msgText += QString(STR_DONATE) + STR_CRLF + STR_CRLF;
+    msgText += STR_COPYRIGHT;
+    QMessageBox::about(this, tr("About DigiClock"),msgText);
 }
 
 void SettingsDialog::showQtAbout()
