@@ -2,6 +2,7 @@
 #define SETTINGSDIALOG_H
 
 #include <QDialog>
+#include <QPushButton>
 
 namespace Ui {
     class SettingsDialog;
@@ -12,19 +13,30 @@ class SettingsDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit SettingsDialog(QWidget *parent = 0);
+    explicit SettingsDialog(QString &aAppletId, QWidget *parent = 0);
     ~SettingsDialog();
 
     void dumpSettings() const;
 
 public slots:
     void btnColorClicked();
+    void fontChanged(int aIndex);
+
+private slots:
+    void showAbout();
+    void showQtAbout();
 
 private:
     void loadSettings();
+    void buildFontList();
+    void fillCbTZ();
+    int calcOffset() const;
 
 private:
+    QString m_appletId;
     Ui::SettingsDialog *ui;
+    QFont m_font;
+//    int m_defTZoffset;
 };
 
 #endif // SETTINGSDIALOG_H
